@@ -1,7 +1,7 @@
 // padthv1.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2022, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -611,7 +611,7 @@ struct padthv1_glide
 			m_freq = m_last;
 			m_step = (m_last - freq) / float(m_frames);
 		} else {
-			m_freq = freq;
+			m_freq = 0.0f;
 			m_step = 0.0f;
 		}
 
@@ -860,7 +860,7 @@ class padthv1_impl
 {
 public:
 
-	padthv1_impl(padthv1 *pSampl, uint16_t nchannels, float srate);
+	padthv1_impl(padthv1 *pSampl, uint16_t nchannels, float srate, uint32_t nsize);
 
 	~padthv1_impl();
 
@@ -1042,8 +1042,8 @@ padthv1_voice::padthv1_voice ( padthv1_impl *pImpl ) :
 	dcf18(&pImpl->dcf1_formant),
 	gen1_glide1(pImpl->gen1_last1),
 	gen1_glide2(pImpl->gen1_last2),
-	out1_volume(1.0f),
 	out1_panning(0.0f),
+	out1_volume(1.0f),
 	sustain(false)
 {
 }
@@ -1052,7 +1052,7 @@ padthv1_voice::padthv1_voice ( padthv1_impl *pImpl ) :
 // engine constructor
 
 padthv1_impl::padthv1_impl (
-	padthv1 *pSampl, uint16_t nchannels, float srate )
+	padthv1 *pSampl, uint16_t nchannels, float srate, uint32_t nsize )
 	: gen1_sample1(pSampl, 1), gen1_sample2(pSampl, 2),
 		m_controls(pSampl), m_programs(pSampl),
 		m_midi_in(pSampl), m_bpm(180.0f), m_nvoices(0), m_running(false)
@@ -1107,6 +1107,9 @@ padthv1_impl::padthv1_impl (
 	// set default sample rate
 	setSampleRate(srate);
 
+	// set default buffer size
+	setBufferSize(nsize);
+
 	// reset all voices
 	allControllersOff();
 	allNotesOff();
@@ -2273,9 +2276,9 @@ bool padthv1_impl::running ( bool on )
 // padthv1 - decl.
 //
 
-padthv1::padthv1 ( uint16_t nchannels, float srate )
+padthv1::padthv1 ( uint16_t nchannels, float srate, uint32_t nsize )
 {
-	m_pImpl = new padthv1_impl(this, nchannels, srate);
+	m_pImpl = new padthv1_impl(this, nchannels, srate, nsize);
 }
 
 
