@@ -1,7 +1,7 @@
 // padthv1.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2022, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -43,7 +43,7 @@ class padthv1
 {
 public:
 
-	padthv1(uint16_t nchannels = 2, float srate = 44100.0f);
+	padthv1(uint16_t nchannels = 2, float srate = 44100.0f, uint32_t nsize = 1024);
 
 	virtual ~padthv1();
 
