@@ -1,7 +1,7 @@
 // padthv1_param.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -30,7 +30,7 @@
 #include <QTextStream>
 #include <QDir>
 
-#include <math.h>
+#include <cmath>
 
 
 //-------------------------------------------------------------------------
