@@ -1,7 +1,7 @@
 // padthv1widget.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2022, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -77,6 +77,9 @@ padthv1widget::padthv1widget ( QWidget *pParent )
 #endif
 
 	m_ui.setupUi(this);
+#if QT_VERSION < QT_VERSION_CHECK(6, 1, 0)
+	QWidget::setWindowIcon(QIcon(":/images/padthv1.png"));
+#endif
 
 	// Init sched notifier.
 	m_sched_notifier = nullptr;
