@@ -24,6 +24,8 @@
 
 #include "padthv1widget_palette.h"
 
+#include "padthv1widget.h"
+
 #include "padthv1_ui.h"
 
 #include "padthv1_controls.h"
@@ -753,26 +755,29 @@ void padthv1widget_config::accept (void)
 			pConfig->sCustomStyleTheme.clear();
 		pConfig->fRandomizePercent = float(m_ui.RandomizePercentSpinBox->value());
 		int iNeedRestart = 0;
-		if (pConfig->sCustomStyleTheme != sOldCustomStyleTheme) {
-			if (pConfig->sCustomStyleTheme.isEmpty()) {
-				++iNeedRestart;
-			} else {
-				QApplication::setStyle(
-					QStyleFactory::create(pConfig->sCustomStyleTheme));
+		QWidget *pParentWidget = parentWidget();
+		if (pParentWidget) {
+			if (pConfig->sCustomStyleTheme != sOldCustomStyleTheme) {
+				if (pConfig->sCustomStyleTheme.isEmpty()) {
+					++iNeedRestart;
+				} else {
+					pParentWidget->setStyle(
+						QStyleFactory::create(pConfig->sCustomStyleTheme));
+				}
 			}
- 		}
- 		if (pConfig->sCustomColorTheme != sOldCustomColorTheme) {
-			if (pConfig->sCustomColorTheme.isEmpty()) {
-				++iNeedRestart;
-			} else {
-				QPalette pal;
-				if (padthv1widget_palette::namedPalette(
-						pConfig, pConfig->sCustomColorTheme, pal))
-					QApplication::setPalette(pal);
+			if (pConfig->sCustomColorTheme != sOldCustomColorTheme) {
+				if (pConfig->sCustomColorTheme.isEmpty()) {
+					++iNeedRestart;
+				} else {
+					QPalette pal;
+					if (padthv1widget_palette::namedPalette(
+							pConfig, pConfig->sCustomColorTheme, pal))
+						pParentWidget->setPalette(pal);
+				}
 			}
- 		}
+		}
 		// Show restart message if needed...
- 		if (iNeedRestart > 0) {
+		if (iNeedRestart > 0) {
 			QMessageBox::information(this,
 				tr("Information"),
 				tr("Some settings may be only effective\n"
